==> evolution-1.3.0.zip: evolution-1.3.0/assets/modules/store/lang/russian-UTF8.php <==
<?php
/*List pack */
$_Lang['version'] = "Версия";
$_Lang['author'] = "Автор";
$_Lang['date'] = "Выпущен";
$_Lang['downloads'] = "Загружен";
$_Lang['install'] = "Установить";
$_Lang['reinstall'] = "Переустановить";
$_Lang['update'] = "Обновить";
$_Lang['installed'] = "Установлен";
$_Lang['installed2'] = "Установлен";
$_Lang['exit'] = "Выход";
$_Lang['alert_overwrite'] = "Установка данного дополнения перезапишет существующие. Продолжить?";

/*Main*/
$_Lang['store_name'] = "Управление пакетами";
$_Lang['version_evailble'] = "Доступна новая версия";
$_Lang['category'] = "Категории";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Войти в свой репозиторий";
$_Lang['password'] = "Пароль";
$_Lang['enter'] = "Войти";
$_Lang['email'] = "Email";
$_Lang['register'] = "Зарегистрироваться";
$_Lang['own_repository'] = "Мой репозиторий";
$_Lang['login_errors'] = "Неправильный Email или пароль";

/* &tpl filters */
$_Lang['s1_1_reated_on'] = "Дата создания";
$_Lang['s1_2_name'] = "Названию";
$_Lang['s1_3_position'] = "Позиции";
$_Lang['s1_4_published'] = "Опубликован";
$_Lang['s2_1_up'] = "По убыванию";
$_Lang['s2_2_down'] = "Возрастание";
$_Lang['search'] = "Поиск по категории: ";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/ru/faq/whatfor.html" target="_blank">Зачем свой репозиторий</a></li>
<li><a href="http://extras.evolution-cms.com/ru/faq/howtoadd.html" target="_blank">Как добавить пакет в репозиторий</a></li>
<li><a href="http://extras.evolution-cms.com/ru/faq/howtocollect.html" target="_blank">Как правильно собрать пакет для установки</a></li>';

?>

==> evolution-1.4.5.zip: evolution-1.4.5/assets/modules/store/lang/russian-UTF8.php <==
<?php
/*List pack */
$_Lang['version'] = "Версия";
$_Lang['author'] = "Автор";
$_Lang['date'] = "Выпущен";
$_Lang['downloads'] = "Загружен";
$_Lang['install'] = "Установить";
$_Lang['reinstall'] = "Переустановить";
$_Lang['update'] = "Обновить";
$_Lang['installed'] = "Установлен";
$_Lang['installed2'] = "Установлен";
$_Lang['exit'] = "Выход";
$_Lang['alert_overwrite'] = "Установка данного дополнения перезапишет существующие. Продолжить?";

/*Main*/
$_Lang['store_name'] = "Управление пакетами";
$_Lang['version_evailble'] = "Доступна новая версия";
$_Lang['category'] = "Категории";

/*Login form*/
$_Lang['enter_in_own_repository'] = "Войти в свой репозиторий";
$_Lang['password'] = "Пароль";
$_Lang['enter'] = "Войти";
$_Lang['email'] = "Email";
$_Lang['register'] = "Зарегистрироваться";
$_Lang['own_repository'] = "Мой репозиторий";
$_Lang['login_errors'] = "Неправильный Email или пароль";

/* &tpl filters */
$_Lang['s1_1_reated_on'] = "Дата создания";
$_Lang['s1_2_name'] = "Названию";
$_Lang['s1_3_position'] = "Позиции";
$_Lang['s1_4_published'] = "Опубликован";
$_Lang['s2_1_up'] = "По убыванию";
$_Lang['s2_2_down'] = "Возрастание";
$_Lang['search'] = "Поиск по категории: ";

/* Installation by file-upload */
$_Lang['install_file'] = "Установка из архива";
$_Lang['choose_file_msg'] = "Выберите файл";
$_Lang['install_file_btn'] = "Установить";
$_Lang['install_file_success'] = "Установка завершена";

/* faq */
$_Lang['faq'] = '
<li><a href="http://extras.evolution-cms.com/ru/faq/whatfor.html" target="_blank">Зачем свой репозиторий</a></li>
<li><a href="http://extras.evolution-cms.com/ru/faq/howtoadd.html" target="_blank">Как добавить пакет в репозиторий</a></li>
<li><a href="http://extras.evolution-cms.com/ru/faq/howtocollect.html" target="_blank">Как правильно собрать пакет для установки</a></li>';

?>
